@@ -186,7 +186,7 @@ class FoxBaseDevice:
         self.device_info_data = device_response
         #Overwrite device name from user app config
         if device_response.device_name is not None:
-            self.name = device_response.device_name
+            self.name = device_response.device_friendly_name
         return True
 
     async def async_fetch_device_available_data(self):
